@@ -12,8 +12,10 @@ use warnings;
 
 package HTML::FromANSI::Tiny;
 {
-  $HTML::FromANSI::Tiny::VERSION = '0.100';
+  $HTML::FromANSI::Tiny::VERSION = '0.101';
 }
+# git description: v0.100-11-gb12fb90
+
 BEGIN {
   $HTML::FromANSI::Tiny::AUTHORITY = 'cpan:RWSTAUNER';
 }
@@ -25,6 +27,7 @@ qw(
   555  f66  6d6  dd6  99f  f6f  6dd  fff
 );
 
+
 sub new {
   my $class = shift;
   my $self = {
@@ -57,25 +60,52 @@ sub ansi_parser {
 sub css {
   my ($self) = @_;
   my $prefix = $self->{selector_prefix} . '.' . $self->{class_prefix};
-  my $parser = $self->ansi_parser;
+
+  my $styles = $self->_css_class_attr;
 
   my @css = (
-    "${prefix}bold { font-weight: bold; }",
-    "${prefix}dark { opacity: 0.7; }",
-    "${prefix}underline { text-decoration: underline; }",
-    "${prefix}concealed { visibility: hidden; }",
+    map { "${prefix}$_ { " . $self->_css_attr_string($styles->{$_}) . " }" }
+      keys %$styles
   );
 
-  my $i = 0;
-  push @css, map { $prefix . $_ . ' { color: ' . $COLORS[$i++] . '; }' }
-    $parser->foreground_colors;
-  $i = 0;
-  push @css, map { $prefix . $_ . ' { background-color: ' . $COLORS[$i++] . '; }' }
-    $parser->background_colors;
-
   return wantarray ? @css : join('', @css);
 }
 
+sub _css_class_attr {
+  my ($self) = @_;
+  return $self->{_all_styles} ||= do {
+
+    my $parser = $self->ansi_parser;
+    my $styles = {
+      bold      => { 'font-weight'      => 'bold'      },
+      dark      => { 'opacity'          => '0.7'       },
+      underline => { 'text-decoration'  => 'underline' },
+      concealed => { 'visibility'       => 'hidden'    },
+    };
+    {
+      my $i = 0;
+      foreach my $fg ( $parser->foreground_colors ){
+        $styles->{$fg} = { color => $COLORS[$i++] };
+      }
+      $i = 0;
+      foreach my $bg ( $parser->background_colors ){
+        $styles->{$bg} = { 'background-color' => $COLORS[$i++] };
+      }
+    }
+
+    # return
+    +{
+      %$styles,
+      %{ $self->{styles} || {} },
+    };
+  };
+}
+
+sub _css_attr_string {
+  my ($self, $attr) = @_;
+  return join ' ', map { "$_: $attr->{$_};" } keys %$attr;
+}
+
 
 sub html {
   my ($self, $text) = @_;
@@ -84,6 +114,8 @@ sub html {
 
   my $tag    = $self->{tag};
   my $prefix = $self->{class_prefix};
+  # Preload if needed; Don't load if not.
+  my $styles = $self->{inline_style} ? $self->_css_class_attr : {};
 
   local $_;
   my @html = map {
@@ -92,10 +124,13 @@ sub html {
 
     $self->{no_plain_tags} && !@$attr
       ? $h
-      : qq[<$tag class="] .
-        join(' ', map { $prefix . $_ } @$attr) . '">' .
-        $h .
-        qq[</$tag>]
+      : do {
+        sprintf q[<%s %s="%s">%s</%s>], $tag,
+          ($self->{inline_style}
+            ? (style => join ' ', map { $self->_css_attr_string($styles->{$_}) } @$attr)
+            : (class => join ' ', map { $prefix . $_ } @$attr)
+          ), $h, $tag;
+      }
 
   } @$text;
 
@@ -137,22 +172,23 @@ sub import {
 
 1;
 
-
 __END__
+
 =pod
 
-=for :stopwords Randy Stauner ACKNOWLEDGEMENTS html cpan testmatrix url annocpan anno
-bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
-
 =encoding utf-8
 
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS inline hashrefs html cpan testmatrix url
+annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan
+
 =head1 NAME
 
 HTML::FromANSI::Tiny - Easily convert colored command line output to HTML
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 SYNOPSIS
 
@@ -208,6 +244,10 @@ C<html_encode> - Code ref that should encode HTML entities; See L</html_encode>.
 
 =item *
 
+C<inline_style> - Boolean to toggle using inline C<style=""> attributes instead of C<class=""> attributes.
+
+=item *
+
 C<no_plain_tags> - Boolean for omitting the C<tag> when the text has no style attributes; Defaults to false for consistency.
 
 =item *
@@ -216,6 +256,10 @@ C<selector_prefix> - String to prefix each css selector; Blank by default. See L
 
 =item *
 
+C<styles> - Tree of hashrefs for customizing style output (for C<< <style> >> tags or C<inline_style>). See L</CUSTOM STYLES>.
+
+=item *
+
 C<tag> - Alternate tag in which to wrap the HTML; Defaults to C<span>.
 
 =back
@@ -330,6 +374,27 @@ Function wrapped around L</html>.
 
 Everything listed in L</FUNCTIONS> is also available for export upon request.
 
+=head1 CUSTOM STYLES
+
+To override the styles output in the L</style_tag> or L</css> methods
+(or the attributes when C<inline_style> is used)
+pass to the constructor a tree of hashrefs as the C<styles> attribute:
+
+  styles => {
+    underline => {
+      'text-decoration'  => 'underline',
+      'text-shadow'      => '0 2px 2px black',
+    },
+    red => {
+      'color'            => '#f00'
+    },
+    on_bright_green => {
+      'background-color' => '#060',
+    }
+  }
+
+Any styles that are not overridden will get the defaults.
+
 =head1 COMPARISON TO HTML::FromANSI
 
 L<HTML::FromANSI> is a bit antiquated (as of v2.03 released in 2007).
@@ -374,51 +439,11 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/HTML-FromANSI-Tiny>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-FromANSI-Tiny>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/HTML-FromANSI-Tiny>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/H/HTML-FromANSI-Tiny>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=HTML-FromANSI-Tiny>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=HTML::FromANSI::Tiny>
+L<http://metacpan.org/release/HTML-FromANSI-Tiny>
 
 =back
 
@@ -447,4 +472,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
